@@ -1,6 +1,5 @@
 package ZHOUYI::ZhanPu;
 
-use 5.010;
 use strict;
 use warnings;
 use ZHOUYI;
@@ -15,17 +14,14 @@ ZHOUYI::ZhanPu - A util of ZHOUYI modules，divination to judge for the future u
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
 
 use ZHOUYI::ZhanPu;
 
@@ -130,19 +126,6 @@ sub jiegua {
         $msg=zhanbu( $int,  $myao );
      
      } 
-=pod
-    given ($myao) {
-        when ('B') { $msg=zhanbu( $ogua, -1 );  $msg.=zhanbu( $bgua, -1 ); }
-        when ('C') {
-            ( $ogua == 0 )
-              or ( $ogua == 63 )
-              ? ($msg=zhanbu( $ogua, 6 ))
-              : ($msg=zhanbu( $ogua, -1 ))
-        }
-        when ('U') { $msg=zhanbu( $ogua, -1 ) }
-        default    { $msg=zhanbu( $int,  $myao ) }
-    }
-=cut
    return $msg;
 }
 
@@ -167,18 +150,6 @@ sub zhanbu {
          $wydsg= "卦：". $reply1. "\n\n";
          $wydsg.= "爻：".$replyyao."\n".$replyxiang."\n";
         }
-=pod
-    given ($myao) {
-        when (-1) { $wydsg="\n卦：".$reply1. "\n"; }
-        when (6) {
-            $wydsg= "爻：".$syao->[6]."\n    ".$sxiang->[7];
-        }
-        default {
-            $wydsg= "\n卦：". $reply1. "\n\n";
-            $wydsg.= "爻：".$replyyao."\n   ".$replyxiang."\n";
-        }
-    }
-=cut   
    return $wydsg;
 
 }
@@ -277,18 +248,7 @@ sub biangua {
     elsif($bunum == 5){ $maiyao = $dy[0]; $maigua = 0 }
     elsif($bunum == 6){ $maiyao = "C";    $maigua = 0 }
     else {$maiyao = "U";    $maigua = 1 }
-=pod
-    given ( scalar @by ) {
-        when (1) { $maiyao = $by[0]; $maigua = 1 }
-        when (2) { $maiyao = $by[1]; $maigua = 1 }
-        when (3) { $maiyao = "B";    $maigua = 1 }
-        when (4) { $maiyao = $dy[0]; $maigua = 0 }
-        when (5) { $maiyao = $dy[0]; $maigua = 0 }
-        when (6) { $maiyao = "C";    $maigua = 0 }
-        default  { $maiyao = "U";    $maigua = 1 }
-    }
 
-=cut
 #    print "Yaobian:", $maiyao, "\n";
 #    print "Guabian:", $maigua, "\n";
 #    print "@bnum",    "\n";
